betty.subprocess module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.subprocess module

Provide a subprocess API.

exception betty.subprocess.CalledSubprocessError

  Bases: `CalledProcessError`, `SubprocessError`

  Raised when a subprocess was successfully invoked, but subsequently failed during its own execution.

exception betty.subprocess.FileNotFound

  Bases: `FileNotFoundError`, `SubprocessError`

  Raised when a command could not be found.

exception betty.subprocess.SubprocessError

  Bases: `Exception`

  Raised when a subprocess failed.

async betty.subprocess.run_process(runnee: Sequence[str], cwd: Path | None = None, shell: bool = False) → Process

  Run a command in a subprocess.

  Raises:

    betty.subprocess.SubprocessError –